# University of Alberta

### Voiland College of Engineering and Architecture
School of Electrical Engineering and Computer Science
Intelligent Robot Learning Laboratory (IRL Lab)

## Research Study Consent Form

## Study Ttile: Agent Corrections to Pac-Man from the Crowd

## Researchs:

Principal Investigator: Dr. Matthew E. Taylor, EECS Professor. (509) 335-6457
Co-Investigator: Bei Peng, Research Assistant. (509) 336-9903
Co-Investigator: Gabriel V. de la Cruz Jr. (808) 284-8435

You are being asked to take part in a research study carried out by the above researchers.
This form explains the research study and your part in it if you decide to join the study.
Please read the form carefully, taking as much time as you need. Ask the researcher to explain anything you don’t understand.
You can decide not to join the study. If you join the study, you can change your mind later or quit at any time.
There will be no penalty or loss of services or benefits if you decide to not take part in the study or quit later.
This study has been approved for human subject participation by the Washington State University Institutional Review Board.

## What is this study about?

This research study is being done to study the ways on how we can leverage human feedback to improve performance of autonomous systems.
You are being asked to take part because you fall in our specified age range (over 18 years old) and have the basic knowledge in operating a
computer that is necessary for the data collection. Depending on the configuration of the study you are taking part in, it can take about 15-40 minutes
for the off-line setup or 1-1 ½ hours for the on-line setup.

## Are there any benefits to me If I am in this study

There is no direct benefit to you from being in this study.
However, through this study, we can understand more about the benefits of crowdsourcing or human-in-the-loop and
how it can be use to solve problems of navigating robots in the future.
There are potential benefits to educational, consumer, industrial, and military applications.

## Statement of Consent

I give my voluntary consent to take part in this study